<?php

namespace Teknisa\CADFIN\Factories;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Geral\Entities\Contcorr;
use Teknisa\Model\Financeiro\Entities\Sdoccorr;
use Teknisa\Libs\Util\DateUtil;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Teknisa\Model\Geral\Entities\Novocodigo;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;


class Ger08500ContaCorrenteFactory {

    protected $entityManager;
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
    }

    public function getContcorr($codigo, $nrorg){
        $params = array();
        $params['cdreducont'] = $codigo;
        $params['nrorg'] = $nrorg;
        $contcorr = $this->entityManager->getRepository(Contcorr::class)->findOneBy($params);
        return $contcorr;
    }

    public function getSaldoContaCorrente($cdreducont, $dtsdoccorr, $nrorg){
        $params = array();
        $params['cdreducont'] = $cdreducont;
        $params['dtsdoccorr'] = $dtsdoccorr;
        $params['nrorg'] = $nrorg;
        $sdoccorr = $this->entityManager->getRepository(Sdoccorr::class)->findOneBy($params);
        return $sdoccorr;
    }

    public function insereSaldoContaCorrente($dtsdoccorr, $cdreducont, $vrsdoccorr, $vrsdoimpla, $operador, $nrorg){
        
        $sdoccorr = new Sdoccorr();
        $sdoccorr->setDtsdoccorr($dtsdoccorr);
        $sdoccorr->setCdreducont($cdreducont);
        $sdoccorr->setVrsdoccorr($vrsdoccorr);
        $sdoccorr->setVrsdoimpla($vrsdoimpla);
        $sdoccorr->setNrorg($nrorg);
        $sdoccorr->setNrorginclusao($nrorg);
        $sdoccorr->setDtinclusao(DateUtil::getDataAtual());
        $sdoccorr->setCdoperinclusao($operador);
        return $sdoccorr;
    }

    public function execProcAtualizaSaldoBancario(
        $cdreducont, $dataInicial, $vrsdoccorr, $idatualiza
    ){
        $procedure = new StoredProcedure($this->entityManager->getConnection(), 'ATUALIZA_SALDO_BANCARIO');
        $procedure->addParam(new Param('P_CDREDUCONT', Param::PARAM_INPUT, $cdreducont, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTSALDO', Param::PARAM_INPUT, $dataInicial, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_VRSDOCCORR', Param::PARAM_INPUT, $vrsdoccorr, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDATUALIZA', Param::PARAM_INPUT, $idatualiza, Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    
    /**
     * Busca Novo Codigo
     * @param $nrorg
     * @param $cdcontador
     * @return Novocodigo
     */
    public function buscaNovocodigo($nrorg, $cdcontador){
        
        /** @var $params */
        $params = array();
        $params['nrorg']      = $nrorg;
        $params['cdcontador'] = $cdcontador;

        /** @var Novocodigo $novocodigo */
        $novocodigo = $this->entityManager->getRepository(Novocodigo::class)->findOneBy($params);

        return $novocodigo;
    }
	
	/**
     * Atualiza Novo Codigo
     * @param $novocodigo
     * @param $nrsequencial
     * @return Novocodigo
     */
    public function atualizaNovocodigo($novocodigo, $nrsequencial){
        
        $novocodigo->setNrsequencial($nrsequencial);

        return $novocodigo;
    }
    
    
    
    public function insereNovocodigo($nrorg, $cdcontador, $nrsequencial){
       
    	/** @var Novocodigo $novocodigo */
    	$novocodigo = new Novocodigo();
    	$novocodigo->setNrorg($nrorg);
    	$novocodigo->setCdcontador($cdcontador);
    	$novocodigo->setNrsequencial($nrsequencial);
        $novocodigo->setDtinclusao(DateUtil::getDataAtual());
        $novocodigo->setDtultatu(DateUtil::getDataAtual());
        $novocodigo->setIdativo('S');
    	
    	return $novocodigo;
    }

    public function atualizaSaldoImplantado($params) {
        $sql = "UPDATE SDOCCORR
                SET VRSDOIMPLA = :VRSDOIMPLA
                WHERE CDREDUCONT = :CDREDUCONT
                AND DTSDOCCORR = :DTSDOCCORR";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }


}